Testcontainers.Compose.ComposeEnvironment (testcontainers v2.1.0)

Copy Markdown View Source

Represents the started state of a Docker Compose environment.

Summary

Functions

Returns the service struct for the given service name.

Returns the docker host for a service.

Returns the mapped host port for a service and container port.

Functions

get_service(env, service_name)

Returns the service struct for the given service name.

get_service_host(env, service_name)

Returns the docker host for a service.

get_service_port(env, service_name, port)

Returns the mapped host port for a service and container port.