Testcontainers.Compose.ComposeService (testcontainers v2.1.0)

Copy Markdown View Source

A lightweight struct representing a service within a Docker Compose environment.

Summary

Functions

Returns the mapped host port for the given container port.

Functions

mapped_port(service, port)

Returns the mapped host port for the given container port.