A struct with builder functions for creating a Docker Compose configuration.
Summary
Functions
Creates a new DockerCompose configuration.
Sets whether to build images before starting containers.
Adds additional compose files to use with the -f flag.
Sets an environment variable for the compose environment.
Adds a profile to enable when starting compose.
Sets the project name for the compose environment.
Sets the pull policy for compose services.
Sets whether to remove volumes when stopping compose.
Sets the specific services to start. If empty, all services are started.
Sets a wait strategy for a specific service.
Sets the wait timeout in milliseconds.
Functions
Creates a new DockerCompose configuration.
The filepath can be a path to a directory containing a docker-compose.yml file,
or a path to a specific compose file.
Sets whether to build images before starting containers.
Adds additional compose files to use with the -f flag.
Sets an environment variable for the compose environment.
Adds a profile to enable when starting compose.
Sets the project name for the compose environment.
Sets the pull policy for compose services.
Sets whether to remove volumes when stopping compose.
Sets the specific services to start. If empty, all services are started.
Sets a wait strategy for a specific service.
Sets the wait timeout in milliseconds.