Represents the started state of a Docker Compose environment.
Summary
Functions
Returns the service struct for the given service name.
Returns the docker host for a service.
Returns the mapped host port for a service and container port.
Represents the started state of a Docker Compose environment.
Returns the service struct for the given service name.
Returns the docker host for a service.
Returns the mapped host port for a service and container port.