A lightweight struct representing a service within a Docker Compose environment.
Summary
Functions
Returns the mapped host port for the given container port.
A lightweight struct representing a service within a Docker Compose environment.
Returns the mapped host port for the given container port.